pub struct DefaultDeviceSink { /* private fields */ }Expand description
DefaultDeviceSink wraps a rodio::Sink and recreates the underlying
stream and sink if the system default output device changes.
Implementations
Sourceimpl DefaultDeviceSink
impl DefaultDeviceSink
Sourcepub fn append<T>(&self, input: T)
pub fn append<T>(&self, input: T)
Appends a source to the sink, ensuring that the default device is current.
pub fn play(&self)
pub fn pause(&self)
pub fn is_paused(&self) -> bool
pub fn clear(&self)
pub fn skip_one(&self)
pub fn sleep_until_end(&self)
pub fn empty(&self) -> bool
pub fn len(&self) -> usize
pub fn volume(&self) -> f32
pub fn set_volume(&self, value: f32)
pub fn speed(&self) -> f32
pub fn set_speed(&self, value: f32)